===================================
Review Board 1.5 RC 2 Release Notes
===================================


**Release date**: September 19, 2010


New Features
============

* Added Python 2.7 compatibility.

* Added compatibility with PyLucene 3.x. Support for 2.x still remains.
  (:bug:`1449`)

* Added support for review requests without diffs, for image/screenshot
  review.

  As more companies use Review Board, we've seen an increasing demand in
  using it just for image review. We've removed the restriction that
  a review request must have an associated diff. Users can choose to upload
  a diff label, or just keep it diff-free.

  Furthermore, users can now set their repository to
  :guilabel:`(None - Graphics Only)` when creating a review request, which
  makes it clear that the review request will be used for image review. In
  this mode, the review request can never have a diff uploaded.


API Improvements
================

* Added support for the ``?counts-only=1`` query parameter for
  :ref:`draft screenshot lists <webapi2.0-draft-screenshot-list-resource>`.

* Renamed the :ref:`draft screenshot <webapi2.0-draft-screenshot-resource>`
  resource key from ``draft-screenshot`` to ``draft_screenshot``.

* Added support for HTTP DELETE on
  :ref:`screenshot draft resources <webapi2.0-draft-screenshot-resource>`.

* Added the screenshot image URL in the
  :ref:`screenshot resources <webapi2.0-screenshot-resource>`.

* Renamed the ``?interdiff_revision=`` query parameter to
  ``?interdiff-revision=``  on
  :ref:`diff comment resources <webapi2.0-review-diff-comment-resource>`.

* Removed support for HTTP PUT on
  :ref:`review group resources <webapi2.0-review-group-resource>`.
  Issuing this command would just return an error.

* Removed the unused ``whitespace_only`` data from the opcodes results in the
  :ref:`per-file diff resource <webapi2.0-file-diff-resource>`.

* Added support for updating :ref:`diff comments
  <webapi2.0-review-reply-diff-comment-resource>` and
  :ref:`screenshot comments
  <webapi2.0-review-reply-screenshot-comment-resource>` on replies to reviews.
  This allows HTTP PUT to be used on these resources.

* Fixed links to diff and screenshot comment resources when linked to from
  other resources.

* The :ref:`user resource <webapi2.0-user-resource>` resource no longer fails
  with usernames containing a period.

* Added support for HTTP Accept mimetypes on all resources.

* Fixed problems using ``?api_format=`` on HTTP GET, PUT and POST resources.


Bug Fixes
=========

* Several usability problems with screenshot drag-and-drop have been fixed.
  In particular, we now guarantee that the drop area will be on-screen,
  which was a problem before on new review requests.

* Fixed an Internal Server Error when using an SSH-based URL for a repository
  without using a username or password.

* Fixed a CSRF (Cross Site Request Forgery) configuration problem for
  password recovery. The CSRF verification token wasn't being set on the
  recovery form, preventing password recovery from working. (:bug:`1723`)

* Repositories weren't being set as visible by default, forcing administrators
  to specifically make it visible.

* Some errors, such as File Not Found, was failing to show up on the
  New Review Request page.

* Remote Git repositories using the raw URL method would fail when presented
  with a diff containing a short SHA1. We now verify during diff upload that
  only full SHA1s are used. (:bug:`1517`)

* When failing to find an account in Active Directory, we were failing to
  fall back to built-in authentication, essentially locking out the locally
  created administration user. (:bug:`1536`)

* Accessing a review request with a newly auto-created account (using LDAP,
  Active Directory, or NIS) would cause an Internal Server Error due to
  the user's profile not having been created yet. (:bug:`1718`)

* Gecos fields on NIS backends no longer causes authentication failures.
  (:bug:`1793`)
